@@ -249,6 +249,7 @@ extern struct node *m_defs;	/* profile/context structure  */
  * their values and reloading the various modules, nmh will run
  * on any system.
  */
+extern char *buildmimeproc;
 extern char *catproc;
 extern char *components;
 extern char *context;
@@ -272,7 +273,6 @@ extern char *mh_seq;
 extern char *mhlformat;
 extern char *mhlforward;
 extern char *mhlproc;
-extern char *mhnproc;
 extern char *moreproc;
 extern char *msgprot;
 extern char *mshproc;
@@ -287,6 +287,7 @@ extern char *replcomps;
 extern char *rmfproc;
 extern char *rmmproc;
 extern char *sendproc;
+extern char *showmimeproc;
 extern char *showproc;
 extern char *slocalproc;
 extern char *sysed;
