@@ -706,7 +706,7 @@ losing1: ;
 	fclose (fp);
 	return RP_BHST;
     }
-    fseek (fp, 0L, 0);
+    fseek (fp, 0L, SEEK_SET);
     for (dp = cp, i = 0; i++ < j; dp += strlen (dp))
 	if (fgets (dp, cc - (dp - cp), fp) == NULL) {
 	    sm_reply.length = strlen (strcpy (sm_reply.text, "premature eof"));
@@ -797,7 +797,7 @@ bad_addr: ;
 			     "To: %*.*s\r\nSubject: Invalid addresses (%s)\r\n",
 			     l - 4, l - 4, sender + 1, file);
 		    fprintf (gp, "Date: %s\r\nFrom: Postmaster@%s\r\n\r\n",
-			     dtimenow (), LocalName ());
+			     dtimenow (0), LocalName ());
 		}
 		if (bp = strchr(dp, '\r'))
 		    *bp = NULL;
@@ -862,7 +862,7 @@ bad_data: ;
 	    goto losing1;
 	}
     }
-    fseek (fp, pos, 0);
+    fseek (fp, pos, SEEK_SET);
     for (;;) {
 	int	eof = 0;
 
@@ -933,7 +933,7 @@ no_dice: ;
 	    if (gp) {
 		fflush (gp);
 		ftruncate (fileno (gp), 0L);
-		fseek (gp, 0L, 0);
+		fseek (gp, 0L, SEEK_SET);
 	    }
     	    else {
 		sprintf (buffer, "%*.*sA.bulk", k, k, file);
@@ -945,13 +945,13 @@ no_dice: ;
 	    fprintf (gp, "To: %*.*s\r\nSubject: Failed mail (%s)\r\n",
 		     i - 4, i - 4, sender + 1, file);
             fprintf (gp, "Date: %s\r\nFrom: Postmaster@%s\r\n\r\n",
-		     dtimenow (), LocalName ());
+		     dtimenow (0), LocalName ());
 	    break;
     }
 
     if (gp) {
 	fputs ("\r\n------- Begin Returned message\r\n\r\n", gp);
-	fseek (fp, pos, 0);
+	fseek (fp, pos, SEEK_SET);
 	while (fgets (buffer, sizeof buffer, fp)) {
 	    if (buffer[0] == '-')
 		fputs ("- ", gp);
@@ -1047,7 +1047,7 @@ smtalk (int time, char *fmt, ...)
 	    case SM_RSET:
 		fflush (sm_wfp);
 		ftruncate (fileno (sm_wfp), 0L);
-		fseek (sm_wfp, 0L, 0);
+		fseek (sm_wfp, 0L, SEEK_SET);
 	        result = 250;
 		break;
 
@@ -1180,16 +1180,16 @@ smhear (void)
     char **ehlo, buffer[BUFSIZ];
 
     if (doingEHLO) {
-	static	int	at_least_once = 0;
+	static int at_least_once = 0;
 
 	if (at_least_once) {
-	    char   *ep;
+	    char *ep;
 
 	    for (ehlo = EHLOkeys; ep = *ehlo; ehlo++)
 		free (ep);
-	}
-	else
+	} else {
 	    at_least_once = 1;
+	}
 
 	*(ehlo = EHLOkeys) = NULL;
     }
@@ -1210,7 +1210,7 @@ again: ;
 	        && (buffer[3] == '-' || doingEHLO == 2)
 	        && buffer[4]) {
 	    if (doingEHLO == 2) {
-		int	len = strlen (buffer + 4);
+		int len = strlen (buffer + 4);
 
 		if ((*ehlo = malloc ((size_t) (strlen (buffer + 4) + 1)))) {
 		    strcpy (*ehlo++, buffer + 4);
