@@ -31,8 +31,8 @@ static int get_x400_comp (char *, char *, char *);
 
 
 /*
- * test if string "sub" appears anywhere in string "str"
- * (case insensitive).
+ * test if string "sub" appears anywhere in
+ * string "str" (case insensitive).
  */
 
 static int
@@ -42,7 +42,7 @@ match (char *str, char *sub)
     register char *s1, *s2;
 
 #ifdef LOCALE
-    while (c1 = *sub) {
+    while ((c1 = *sub)) {
 	c1 = (isalpha(c1) && isupper(c1)) ? tolower(c1) : c1;
 	while ((c2 = *str++) && c1 != ((isalpha(c2) && isupper(c2)) ? tolower(c2) : c2))
 	    ;
@@ -110,7 +110,7 @@ match (char *str, char *sub)
 			i = -i;\
 			ljust++;\
 		}\
-		if (sp = (str)) {\
+		if ((sp = (str))) {\
 			if (ljust) {\
 				c = strlen(sp);\
 				if (c > i)\
@@ -121,14 +121,14 @@ match (char *str, char *sub)
 					i++;\
 				}\
 			} else {\
-			    while ((c = *sp) && (iscntrl(c) || isspace(c)))\
+			    while ((c = (unsigned char) *sp) && (iscntrl(c) || isspace(c)))\
 				sp++;\
 			}\
-			while ((c = *sp++) && --i >= 0 && cp < ep)\
+			while ((c = (unsigned char) *sp++) && --i >= 0 && cp < ep)\
 				if (isgraph(c)) \
 				    *cp++ = c;\
 				else {\
-					while ((c = *sp) && (iscntrl(c) || isspace(c)))\
+					while ((c = (unsigned char) *sp) && (iscntrl(c) || isspace(c)))\
 						sp++;\
 					    *cp++ = ' ';\
 				}\
@@ -138,14 +138,14 @@ match (char *str, char *sub)
 		    *cp++ = fill;\
 	}
 #define PUTS(cp, str) {\
-		if (sp = (str)) {\
-		    while ((c = *sp) && (iscntrl(c) || isspace(c)))\
+		if ((sp = (str))) {\
+		    while ((c = (unsigned char) *sp) && (iscntrl(c) || isspace(c)))\
 			sp++;\
-		    while((c = *sp++) && cp < ep)\
+		    while((c = (unsigned char) *sp++) && cp < ep)\
 			if (isgraph(c)) \
 			    *cp++ = c;\
 			else {\
-			    while ((c = *sp) && (iscntrl(c) || isspace(c)))\
+			    while ((c = (unsigned char) *sp) && (iscntrl(c) || isspace(c)))\
 				sp++;\
 			    *cp++ = ' ';\
 			}\
@@ -253,21 +253,20 @@ get_x400_comp (char *mbox, char *key, char *buffer)
 struct format *
 fmt_scan (struct format *format, char *scanl, int width, int *dat)
 {
-    register char *cp = scanl;
-    register char *ep = scanl + width - 1;
-    register struct format *fmt = format;
-    register char *str = NULL;
-    register int value = 0;
-    register char *sp;
-    register int i;
-    register int c;
-    register struct comp *comp;
-    register struct tws *tws;
-    register struct mailname *mn;
-    int ljust;
-    time_t t;
-    char *savestr;
+    char *cp, *ep, *sp;
+    char *savestr, *str = NULL;
     char buffer[BUFSIZ];
+    int i, c, ljust;
+    int value = 0;
+    time_t t;
+    struct format *fmt;
+    struct comp *comp;
+    struct tws *tws;
+    struct mailname *mn;
+
+    cp = scanl;
+    ep = scanl + width - 1;
+    fmt = format;
 
     while (cp < ep) {
 	switch (fmt->f_type) {
@@ -512,11 +511,11 @@ fmt_scan (struct format *format, char *scanl, int width, int *dat)
 	    str = dtwszone (fmt->f_comp->c_tws);
 	    break;
 	case FT_LV_YEAR:
-#ifndef	YEARMOD
+#ifndef YEARMOD
 	    value = fmt->f_comp->c_tws->tw_year;
-#else	/* YEARMOD */
+#else /* YEARMOD */
 	    value = (fmt->f_comp->c_tws->tw_year) % 100;
-#endif	/* YEARMOD */
+#endif /* YEARMOD */
 	    break;
 	case FT_LV_WDAY:
 	    if (!(((tws = fmt->f_comp->c_tws)->tw_flags) & (TW_SEXP|TW_SIMP)))
@@ -541,12 +540,12 @@ fmt_scan (struct format *format, char *scanl, int width, int *dat)
 	    break;
 	case FT_LV_CLOCK:
 	    if ((value = fmt->f_comp->c_tws->tw_clock) == 0)
-		value = twclock(fmt->f_comp->c_tws);
+		value = dmktime(fmt->f_comp->c_tws);
 	    break;
 	case FT_LV_RCLOCK:
 	    if ((value = fmt->f_comp->c_tws->tw_clock) == 0)
-		value = twclock(fmt->f_comp->c_tws);
-	    value = time((long *) 0) - value;
+		value = dmktime(fmt->f_comp->c_tws);
+	    value = time((time_t *) 0) - value;
 	    break;
 	case FT_LV_DAYF:
 	    if (!(((tws = fmt->f_comp->c_tws)->tw_flags) & (TW_SEXP|TW_SIMP)))
@@ -569,10 +568,10 @@ fmt_scan (struct format *format, char *scanl, int width, int *dat)
 	    value = fmt->f_comp->c_tws->tw_flags & TW_DST;
 	    break;
 	case FT_LS_822DATE:
-	    str = dasctime ( fmt->f_comp->c_tws , TW_ZONE);
+	    str = dasctime (fmt->f_comp->c_tws , TW_ZONE);
 	    break;
 	case FT_LS_PRETTY:
-	    str = dasctime ( fmt->f_comp->c_tws, TW_NULL);
+	    str = dasctime (fmt->f_comp->c_tws, TW_NULL);
 	    break;
 
 	case FT_LS_PERS:
@@ -609,7 +608,7 @@ fmt_scan (struct format *format, char *scanl, int width, int *dat)
 	case FT_LS_FRIENDLY:
 #ifdef BERK
 	    str = fmt->f_comp->c_mn->m_mbox;
-#else	/* not BERK */
+#else /* not BERK */
 	    if ((mn = fmt->f_comp->c_mn) == &fmt_mnull) {
 		str = fmt->f_comp->c_text;
 		break;
@@ -651,13 +650,13 @@ fmt_scan (struct format *format, char *scanl, int width, int *dat)
 			break;
 		  }
 		}
-#endif	/* BERK */
+#endif /* BERK */
 	    break;
 
 	case FT_LOCALDATE:
 	    comp = fmt->f_comp;
 	    if ((t = comp->c_tws->tw_clock) == 0)
-		t = twclock(comp->c_tws);
+		t = dmktime(comp->c_tws);
 	    tws = dlocaltime(&t);
 	    *comp->c_tws = *tws;
 	    break;
@@ -665,7 +664,7 @@ fmt_scan (struct format *format, char *scanl, int width, int *dat)
 	case FT_GMTDATE:
 	    comp = fmt->f_comp;
 	    if ((t = comp->c_tws->tw_clock) == 0)
-		t = twclock(comp->c_tws);
+		t = dmktime(comp->c_tws);
 	    tws = dgmtime(&t);
 	    *comp->c_tws = *tws;
 	    break;
@@ -772,13 +771,13 @@ fmt_scan (struct format *format, char *scanl, int width, int *dat)
 	    break;
 
 	case FT_ADDTOSEQ:
-#ifdef	LBL
+#ifdef LBL
 	    /* If we're working on a folder (as opposed to a file), add the
 	     * current msg to sequence given in literal field.  Don't
 	     * disturb string or value registers.
 	     */
 	    if (fmt_current_folder)
-		    m_seqadd(fmt_current_folder, fmt->f_text, dat[0], -1);
+		    seq_addmsg(fmt_current_folder, fmt->f_text, dat[0], -1);
 #endif
 	    break;
 	}
@@ -790,7 +789,7 @@ fmt_scan (struct format *format, char *scanl, int width, int *dat)
 	*cp++ = '\n';
     *cp   = 0;
     return ((struct format *)0);
-#else	/* JLR */
+#else /* JLR */
     if (cp[-1] != '\n')
 	*cp++ = '\n';
     while (fmt->f_type != FT_DONE)
@@ -798,7 +797,7 @@ fmt_scan (struct format *format, char *scanl, int width, int *dat)
 
     finished:;    
     *cp = '\0';
-    return (fmt->f_value ? ++fmt : (struct format *)0);
+    return (fmt->f_value ? ++fmt : (struct format *) 0);
 
 #endif /* JLR */
 }
