@@ -46,7 +46,7 @@ m_draft (char *folder, char *msg, int use, int *isdf)
     if (chdir (buffer) == NOTOK)
 	adios (buffer, "unable to change directory to");
 
-    if (!(mp = m_gmsg (folder)))
+    if (!(mp = m_readfolder (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
     if ((mp = m_remsg (mp, 0, MAXFOLDER)) == NULL)
@@ -55,16 +55,17 @@ m_draft (char *folder, char *msg, int use, int *isdf)
 
     if (!m_convert (mp, msg && *msg ? msg : use ? "cur" : "new"))
 	done (1);
-    m_setseq (mp);
+    seq_setprev (mp);
+
     if (mp->numsel > 1)
 	adios (NULL, "only one message draft at a time!");
 
     sprintf (buffer, "%s/%s", mp->foldpath, m_name (mp->lowsel));
     cp = buffer;
 
-    m_setcur (mp, mp->lowsel);
-    m_sync (mp);
-    m_fmsg (mp);		/* free folder/message info */
+    seq_setcur (mp, mp->lowsel);/* set current message for folder */
+    seq_save (mp);		/* synchronize message sequences  */
+    m_freefolder (mp);		/* free folder/message info       */
 
     return cp;
 }
