@@ -612,12 +612,12 @@ m_Eom (int c, FILE *iob)
 	     */
 	    return 1;
 
-#ifdef notdef
+#if 0
 	fseek (iob, pos, SEEK_SET);
-#else
+#endif
+
 	fseek (iob, (long)(pos-1), SEEK_SET);
 	getc (iob);		/* should be OK */
-#endif /* !notdef */
 	return 0;
     }
 
@@ -698,18 +698,6 @@ get_returnpath (char *rp, char *dd)
 #endif /* RPATHS */
 
 
-#if (vax && !lint)
-	asm(".align 1");
-	asm("_matchc: .word 0");
-	asm("	movq 4(ap),r0");
-	asm("	movq 12(ap),r2");
-	asm("	matchc  r0,(r1),r2,(r3)");
-	asm("	beql 1f");
-	asm("	movl 4(ap),r3");
-	asm("1:	subl3  4(ap),r3,r0");
-	asm("	ret");
-#else
-
 static unsigned char *
 matchc(int patln, char *pat, int strln, char *str)
 {
@@ -731,22 +719,12 @@ matchc(int patln, char *pat, int strln, char *str)
 			return ((unsigned char *)--str);
 	}
 }
-#endif
 
 
 /*
  * Locate character "term" in the next "cnt" characters of "src".
  * If found, return its address, otherwise return 0.
  */
-#if (vax && !lint)
-	asm(".align 1");
-	asm("_locc: .word 0");
-	asm("	movq  4(ap),r0");
-	asm("	locc  12(ap),r0,(r1)");
-	asm("	beql  1f");
-	asm("	movl  r1,r0");
-	asm("1:	ret");
-#else
 
 static unsigned char *
 locc(int cnt, unsigned char *src, unsigned char term)
@@ -755,5 +733,4 @@ locc(int cnt, unsigned char *src, unsigned char term)
 
     return (cnt > 0 ? --src : (unsigned char *)0);
 }
-#endif
 
