@@ -14,29 +14,30 @@ struct procstr {
 };
 
 static struct procstr procs[] = {
-    { "context",      &context },
-    { "mh-sequences", &mh_seq },
-    { "faceproc",     &faceproc },
-    { "fileproc",     &fileproc },
-    { "incproc",      &incproc },
-    { "installproc",  &installproc },
-    { "lproc",        &lproc },
-    { "mailproc",     &mailproc },
-    { "mhlproc",      &mhlproc },
-    { "mhnproc",      &mhnproc },
-    { "moreproc",     &moreproc },
-    { "mshproc",      &mshproc },
-    { "packproc",     &packproc },
-    { "postproc",     &postproc },
-    { "rmfproc",      &rmfproc },
-    { "rmmproc",      &rmmproc },
-    { "sendproc",     &sendproc },
-    { "showproc",     &showproc },
-    { "slocalproc",   &slocalproc },
-    { "vmhproc",      &vmhproc },
-    { "whatnowproc",  &whatnowproc },
-    { "whomproc",     &whomproc },
-    { NULL,           NULL }
+    { "context",       &context },
+    { "mh-sequences",  &mh_seq },
+    { "buildmimeproc", &buildmimeproc },
+    { "faceproc",      &faceproc },
+    { "fileproc",      &fileproc },
+    { "incproc",       &incproc },
+    { "installproc",   &installproc },
+    { "lproc",         &lproc },
+    { "mailproc",      &mailproc },
+    { "mhlproc",       &mhlproc },
+    { "moreproc",      &moreproc },
+    { "mshproc",       &mshproc },
+    { "packproc",      &packproc },
+    { "postproc",      &postproc },
+    { "rmfproc",       &rmfproc },
+    { "rmmproc",       &rmmproc },
+    { "sendproc",      &sendproc },
+    { "showmimeproc",  &showmimeproc },
+    { "showproc",      &showproc },
+    { "slocalproc",    &slocalproc },
+    { "vmhproc",       &vmhproc },
+    { "whatnowproc",   &whatnowproc },
+    { "whomproc",      &whomproc },
+    { NULL,            NULL }
 };
 
 static struct node **opp = NULL;
