@@ -49,10 +49,8 @@ makedir (char *dir)
 		    advise (dir, "unable to create directory");
 		    return 0;
 	    }
-    }
-    else
-
-    switch (pid = vfork()) {
+    } else {
+	switch (pid = vfork()) {
 	case NOTOK: 
 	    advise ("fork", "unable to");
 	    return 0;
@@ -71,6 +69,7 @@ makedir (char *dir)
 	    if (pidXwait(pid, "mkdir"))
 		return 0;
 	    break;
+	}
     }
 
     if ((cp = m_find ("folder-protect")) == NULL)
