@@ -36,7 +36,7 @@ pidstatus (int status, FILE *fp, char *cp)
 
     switch (signum) {
 	case OK: 
-	    if (signum = ((status & 0xff00) >> 8)) {
+	    if ((signum = ((status & 0xff00) >> 8))) {
 		if (cp)
 		    fprintf (fp, "%s: ", cp);
 		fprintf (fp, "exit %d\n", signum);
