@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 
 void
@@ -21,7 +21,7 @@ print_sw (char *substr, struct swit *swp, char *prefix)
 	if (!*substr ||		/* null matches all strings */
 		(ssequal (substr, swp->sw) && len >= swp->minchars)) {
 	    optno = 0;
-	    if (sp = (&swp[1])->sw) /* next switch */
+	    if ((sp = (&swp[1])->sw)) /* next switch */
 		if (!*substr && sp[0] == 'n' && sp[1] == 'o' &&
 			strcmp (&sp[2], swp->sw) == 0 && (
 			((&swp[1])->minchars == 0 && swp->minchars == 0) ||
@@ -37,11 +37,11 @@ print_sw (char *substr, struct swit *swp, char *prefix)
 		for (cp1 = swp->sw, i = 0; i < swp->minchars; i++)
 		    *cp++ = *cp1++;
 		*cp++ = ')';
-		while (*cp++ = *cp1++);
+		while ((*cp++ = *cp1++));
 		printf ("  %s%s\n", prefix, buf);
 	    }
 	    else
-		if (swp->minchars == 0)
+		if (!swp->minchars)
 		    printf(optno ? "  %s[no]%s\n" : "  %s%s\n", prefix, swp->sw);
 	    if (optno)
 		swp++;	/* skip -noswitch */
