@@ -13,15 +13,15 @@ smatch(char *string, struct swit *swp)
 {
     register char *sp, *tcp;
     struct swit *tp;
-    int firstone, stringlen;
+    int firstone, len;
 
     firstone = UNKWNSW;
 
     if (!string)
 	return firstone;
 
-    for (stringlen = strlen(string), tp = swp; tcp = tp->sw; tp++) {
-	if (stringlen < abs (tp->minchars))
+    for (len = strlen(string), tp = swp; tcp = tp->sw; tp++) {
+	if (len < abs(tp->minchars))
 	    continue;		/* no match */
 	for (sp = string; *sp == *tcp++;) {
 	    if (*sp++ == 0)
