@@ -153,7 +153,7 @@ main (int argc, char **argv)
 	vec[nvec++] = "-dist";
     if (queued)
 	vec[nvec++] = "-queued";
-    vec[nvec] = 0;
+    vec[nvec] = NULL;
 
     for (i = 0; (child_id = fork()) == NOTOK && i < 5; i++)
 	sleep (5);
