@@ -36,35 +36,36 @@ struct proc {
 };
 
 static struct proc procs [] = {
-     { "context",     &context },
-     { "faceproc",    &faceproc },
-     { "fileproc",    &fileproc },
-     { "foldprot",    &foldprot },
-     { "incproc",     &incproc },
-     { "installproc", &installproc  },
-     { "lproc",       &lproc },
-     { "mailproc",    &mailproc },
-     { "mhlproc",     &mhlproc },
-     { "mhnproc",     &mhnproc },
-     { "moreproc",    &moreproc },
-     { "msgprot",     &msgprot },
-     { "mshproc",     &mshproc },
-     { "packproc",    &packproc },
-     { "postproc",    &postproc },
-     { "rmfproc",     &rmfproc },
-     { "rmmproc",     &rmmproc },
-     { "sendproc",    &sendproc },
-     { "showproc",    &showproc },
-     { "slocalproc",  &slocalproc },
-     { "version",     &version },
-     { "vmhproc",     &vmhproc },
-     { "whatnowproc", &whatnowproc },
-     { "whomproc",    &whomproc },
-     { "etcdir",      &mhetcdir },
-     { "libdir",      &mhlibdir },
-     { "sbackup",     &sbackup },
-     { "link",        &slink },
-     { NULL,          NULL },
+     { "context",       &context },
+     { "buildmimeproc", &buildmimeproc },
+     { "faceproc",      &faceproc },
+     { "fileproc",      &fileproc },
+     { "foldprot",      &foldprot },
+     { "incproc",       &incproc },
+     { "installproc",   &installproc  },
+     { "lproc",         &lproc },
+     { "mailproc",      &mailproc },
+     { "mhlproc",       &mhlproc },
+     { "moreproc",      &moreproc },
+     { "msgprot",       &msgprot },
+     { "mshproc",       &mshproc },
+     { "packproc",      &packproc },
+     { "postproc",      &postproc },
+     { "rmfproc",       &rmfproc },
+     { "rmmproc",       &rmmproc },
+     { "sendproc",      &sendproc },
+     { "showmimeproc",  &showmimeproc },
+     { "showproc",      &showproc },
+     { "slocalproc",    &slocalproc },
+     { "version",       &version },
+     { "vmhproc",       &vmhproc },
+     { "whatnowproc",   &whatnowproc },
+     { "whomproc",      &whomproc },
+     { "etcdir",        &mhetcdir },
+     { "libdir",        &mhlibdir },
+     { "sbackup",       &sbackup },
+     { "link",          &slink },
+     { NULL,            NULL },
 };
 
 
@@ -74,6 +75,7 @@ static struct proc procs [] = {
 static char *p_find(char *);
 
 
+int
 main(int argc, char **argv)
 {
     int i, all = 0, compp = 0;
