@@ -2384,7 +2384,7 @@ showcmd (char **args)
     if (!nshow && !getenv ("NOMHNPROC"))
 	for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
 	    if (is_selected (mp, msgnum) && nontext (msgnum)) {
-		proc = mhnproc;
+		proc = showmimeproc;
 		vec[vecp++] = "-show";
 		vec[vecp++] = "-file";
 		vec[vecp] = NULL;
