@@ -618,7 +618,7 @@ plist
     register char *p1, *p2, *ebp, *cbp;
     char ibuf[BUFSIZ];
 
-    fseek (fp, start, 0);
+    fseek (fp, start, SEEK_SET);
     body = 0;
     ebp = cbp = ibuf;
     for (;;) {
@@ -815,7 +815,7 @@ tws_parse (char *ap, int isafter)
     if ((tw = dparsetime (ap)) != NULL)
 	return tw;
 
-    if ((ts = dtwstime ()) == NULL)
+    if ((ts = dlocaltimenow ()) == NULL)
 	return NULL;
 
     sprintf (buffer, "%s %s", ap, dtwszone (ts));
@@ -890,7 +890,7 @@ plist
     char buf[BUFSIZ], name[NAMESZ];
     register struct tws *tw;
 
-    fseek (fp, start, 0);
+    fseek (fp, start, SEEK_SET);
     for (state = FLD, bp = NULL;;) {
 	switch (state = m_getfld (state, name, buf, sizeof buf, fp)) {
 	    case FLD: 
