@@ -437,7 +437,7 @@ replfilter (FILE *in, FILE *out)
 	default: 
 	    if (pidXwait (pid, mhl))
 		done (1);
-	    fseek (out, 0L, 2);
+	    fseek (out, 0L, SEEK_END);
 	    break;
     }
 }
