@@ -78,7 +78,8 @@ static int
 sendaux (char **vec, int vecp, char *drft, struct stat *st)
 {
     int	compnum, nparts, partno, state, status;
-    long clock, pos, start;
+    long pos, start;
+    time_t clock;
     char *cp, *dp, buffer[BUFSIZ], msgid[BUFSIZ];
     char name[NAMESZ], partnum[BUFSIZ];
     struct stat sts;
@@ -182,9 +183,10 @@ one_shot: ;
 	vec[vecp++] = "-queued";
 
     time (&clock);
-    sprintf (msgid, "<%d.%ld@%s>", getpid(), clock, LocalName());
+    sprintf (msgid, "<%d.%ld@%s>", (int) getpid(),
+		(long) clock, LocalName());
 
-    fseek (in, start, 0);
+    fseek (in, start, SEEK_SET);
     for (partno = 1; partno <= nparts; partno++) {
 	char tmpdrf[BUFSIZ];
 	FILE *out;
@@ -220,7 +222,7 @@ one_shot: ;
 	    }
 	    
 	    if ((pos += (len = strlen (buffer))) > CPERMSG) {
-		fseek (in, -len, 1);
+		fseek (in, -len, SEEK_CUR);
 		break;
 	    }
 
@@ -388,7 +390,7 @@ alert (char *file, int out)
 	    SIGNAL (SIGQUIT, SIG_IGN);
 	    SIGNAL (SIGTERM, SIG_IGN);
 	    if (forwsw) {
-		if ((in = open (file, 0)) == NOTOK) {
+		if ((in = open (file, O_RDONLY)) == NOTOK) {
 		    admonish (file, "unable to re-open");
 		} else {
 		    lseek (out, (off_t) 0, SEEK_END);
@@ -514,7 +516,7 @@ annoaux (int fd)
 	    admonish (maildir, "unable to change directory to");
 	return;
     }
-    if (!(mp = m_gmsg (folder))) {
+    if (!(mp = m_readfolder (folder))) {
 	if (debugsw)
 	    admonish (NULL, "unable to read folder %s");
 	return;
@@ -532,7 +534,7 @@ annoaux (int fd)
     }
     if (!debugsw			/* MOBY HACK... */
 	    && pushsw
-	    && (fd3 = open ("/dev/null", 2)) != NOTOK
+	    && (fd3 = open ("/dev/null", O_RDWR)) != NOTOK
 	    && (fd2 = dup (fileno (stderr))) != NOTOK) {
 	dup2 (fd3, fileno (stderr));
 	close (fd3);
@@ -575,7 +577,7 @@ annoaux (int fd)
     free (cp);
 
 oops: ;
-    m_fmsg (mp);	/* free folder/message info */
+    m_freefolder (mp);	/* free folder/message info */
 }
 
 
