@@ -13,23 +13,23 @@
 
 static struct swit switches[] = {
 #define	DRFTSW               0
-    { "draft", 5 },
+    { "draft", 0 },
 #define	FORMSW               1
-    { "form formfile", 4 },
+    { "form formfile", 0 },
 #define	PROGSW               2
-    { "moreproc program", 4 },
+    { "moreproc program", 0 },
 #define	NPROGSW              3
-    { "nomoreproc", 3 },
+    { "nomoreproc", 0 },
 #define	LENSW                4
-    { "length lines", 4 },
+    { "length lines", 0 },
 #define	WIDTHSW              5
-    { "width columns", 4 },
-#define	SHOWSW               6
-    { "showproc program", 4 },
-#define	NSHOWSW              7
-    { "noshowproc", 3 },
-#define MHNSW                8
-    { "mhnproc", 3 },
+    { "width columns", 0 },
+#define	NSHOWSW              6
+    { "noshowproc", 0 },
+#define	SHOWSW               7
+    { "showproc program", 0 },
+#define SHOWMIMESW           8
+    { "showmimeproc program", 0 },
 #define CHECKMIMESW          9
     { "checkmime", 0 },
 #define NOCHECKMIMESW       10
@@ -43,7 +43,7 @@ static struct swit switches[] = {
 #define VERSIONSW           14
     { "version", 0 },
 #define	HELPSW              15
-    { "help", 4 },
+    { "help", 0 },
     { NULL, 0 }
 };
 
@@ -51,13 +51,15 @@ static struct swit switches[] = {
  * static prototypes
  */
 #ifdef MIME
-static int nontext(char *);
+static int is_mime(char *);
 #endif
 
 #define	SHOW  0
 #define	NEXT  1
 #define	PREV  2
 
+
+int
 main (int argc, char **argv)
 {
     int draftsw = 0, headersw = 1, msgp = 0;
@@ -159,8 +161,8 @@ main (int argc, char **argv)
 		    nshow++;
 		    continue;
 
-		case MHNSW:
-		    if (!(mhnproc = *argp++) || *mhnproc == '-')
+		case SHOWMIMESW:
+		    if (!(showmimeproc = *argp++) || *showmimeproc == '-')
 			adios (NULL, "missing argument to %s", argp[-2]);
 		    nshow = 0;
 		    continue;
@@ -278,20 +280,20 @@ go_to_it: ;
 	    if (!draftsw && !file) {
 		/* loop through selected messages and check for MIME */
 		for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-		    if (is_selected (mp, msgnum) && nontext (m_name (msgnum))) {
+		    if (is_selected (mp, msgnum) && is_mime (m_name (msgnum))) {
 			mime = 1;
 			break;
 		    }
 	    } else {
 		/* check the file or draft for MIME */
-		if (nontext (vec[vecp - 1]))
+		if (is_mime (vec[vecp - 1]))
 		    mime = 1;
 	    }
 	}
 
 	/* Set the "proc" */
 	if (mime)
-	    proc = mhnproc;
+	    proc = showmimeproc;
 	else
 	    proc = showproc;
     }
@@ -358,11 +360,13 @@ OfficialName (char *name)
     return name;
 }
 
-
 #ifdef MIME
 
+/*
+ * Check if a message or file is a MIME message
+ */
 static int
-nontext (char *msgnam)
+is_mime (char *msgnam)
 {
     int	result, state;
     register char *bp, *dp;
