@@ -43,7 +43,7 @@ rcinit (int rfd, int wfd)
     if ((cp = getenv ("MHVDEBUG")) && *cp) {
 	sprintf (buffer, "%s.out", invo_name);
 	if ((fp = fopen (buffer, "w"))) {
-	  fseek (fp, 0L, 2);
+	  fseek (fp, 0L, SEEK_END);
 	  fprintf (fp, "%d: rcinit (%d, %d)\n", getpid (), rfd, wfd);
 	  fflush (fp);
 	}
@@ -105,7 +105,7 @@ peer2rc (struct record *rc)
 	rc->rc_data = NULL;
 
     if (fp) {
-	fseek (fp, 0L, 2);
+	fseek (fp, 0L, SEEK_END);
 	fprintf (fp, "%d: <--- %s %d: \"%*.*s\"\n", getpid (),
 		types[rc->rc_type], rc->rc_len,
 		rc->rc_len, rc->rc_len, rc->rc_data);
@@ -126,7 +126,7 @@ rc2peer (char code, int len, char *data)
     rc->rc_len = len;
 
     if (fp) {
-	fseek (fp, 0L, 2);
+	fseek (fp, 0L, SEEK_END);
 	fprintf (fp, "%d: ---> %s %d: \"%*.*s\"\n", getpid (),
 		types[rc->rc_type], rc->rc_len,
 		rc->rc_len, rc->rc_len, data);
