@@ -39,22 +39,27 @@ static struct swit whatnowswitches[] = {
     { NULL, 0 }
 };
 
+/*
+ * Options at the "whatnow" prompt
+ */
 static struct swit aleqs[] = {
 #define	DISPSW                         0
     { "display [<switches>]", 0 },
-#define	EDITSW                         1
+#define BUILDMIMESW                    1
+    { "mime [<switches>]", 0 },
+#define	EDITSW                         2
     { "edit [<editor> <switches>]", 0 },
-#define	LISTSW                         2
+#define	LISTSW                         3
     { "list [<switches>]", 0 },
-#define	PUSHSW                         3
+#define	PUSHSW                         4
     { "push [<switches>]", 0 },
-#define	QUITSW                         4
+#define	QUITSW                         5
     { "quit [-delete]", 0 },
-#define	REFILEOPT                      5
+#define	REFILEOPT                      6
     { "refile [<switches>] +folder", 0 },
-#define	SENDSW                         6
+#define	SENDSW                         7
     { "send [<switches>]", 0 },
-#define	WHOMSW                         7
+#define	WHOMSW                         8
     { "whom [<switches>]", 0 },
     { NULL, 0 }
 };
@@ -67,6 +72,7 @@ static char *myprompt = "\nWhat now? ";
 static int editfile (char **, char **, char *, int, struct msgs *, char *, char *);
 static int sendfile (char **, char *, int);
 static void sendit (char *, char **, char *, int);
+static int build_mime (char **, char *);
 static int whomfile (char **, char *);
 
 #ifdef HAVE_LSTAT
@@ -92,9 +98,9 @@ WhatNow (int argc, char **argv)
     if ((cp = m_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
@@ -102,52 +108,52 @@ WhatNow (int argc, char **argv)
     while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, whatnowswitches)) {
-		case AMBIGSW: 
-		    ambigsw (cp, whatnowswitches);
-		    done (1);
-		case UNKWNSW: 
-		    adios (NULL, "-%s unknown", cp);
+	    case AMBIGSW: 
+		ambigsw (cp, whatnowswitches);
+		done (1);
+	    case UNKWNSW: 
+		adios (NULL, "-%s unknown", cp);
 
-		case HELPSW: 
-		    sprintf (buf, "%s [switches] [file]", invo_name);
-		    print_help (buf, whatnowswitches);
-		    done (1);
-		case VERSIONSW:
-		    print_version(invo_name);
-		    done (1);
+	    case HELPSW: 
+		sprintf (buf, "%s [switches] [file]", invo_name);
+		print_help (buf, whatnowswitches);
+		done (1);
+	    case VERSIONSW:
+		print_version(invo_name);
+		done (1);
 
-		case DFOLDSW: 
-		    if (dfolder)
-			adios (NULL, "only one draft folder at a time!");
-		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULL, "missing argument to %s", argp[-2]);
-		    dfolder = path (*cp == '+' || *cp == '@' ? cp + 1 : cp,
-			    *cp != '@' ? TFOLDER : TSUBCWF);
-		    continue;
-		case DMSGSW: 
-		    if (dmsg)
-			adios (NULL, "only one draft message at a time!");
-		    if (!(dmsg = *argp++) || *dmsg == '-')
-			adios (NULL, "missing argument to %s", argp[-2]);
-		    continue;
-		case NDFLDSW: 
-		    dfolder = NULL;
-		    isdf = NOTOK;
-		    continue;
+	    case DFOLDSW: 
+		if (dfolder)
+		    adios (NULL, "only one draft folder at a time!");
+		if (!(cp = *argp++) || *cp == '-')
+		    adios (NULL, "missing argument to %s", argp[-2]);
+		dfolder = path (*cp == '+' || *cp == '@' ? cp + 1 : cp,
+				*cp != '@' ? TFOLDER : TSUBCWF);
+		continue;
+	    case DMSGSW: 
+		if (dmsg)
+		    adios (NULL, "only one draft message at a time!");
+		if (!(dmsg = *argp++) || *dmsg == '-')
+		    adios (NULL, "missing argument to %s", argp[-2]);
+		continue;
+	    case NDFLDSW: 
+		dfolder = NULL;
+		isdf = NOTOK;
+		continue;
 
-		case EDITRSW: 
-		    if (!(ed = *argp++) || *ed == '-')
-			adios (NULL, "missing argument to %s", argp[-2]);
-		    nedit = 0;
-		    continue;
-		case NEDITSW: 
-		    nedit++;
-		    continue;
+	    case EDITRSW: 
+		if (!(ed = *argp++) || *ed == '-')
+		    adios (NULL, "missing argument to %s", argp[-2]);
+		nedit = 0;
+		continue;
+	    case NEDITSW: 
+		nedit++;
+		continue;
 
-		case PRMPTSW:
-		    if (!(myprompt = *argp++) || *myprompt == '-')
-			adios (NULL, "missing argument to %s", argp[-2]);
-		    continue;
+	    case PRMPTSW:
+		if (!(myprompt = *argp++) || *myprompt == '-')
+		    adios (NULL, "missing argument to %s", argp[-2]);
+		continue;
 	    }
 	if (drft)
 	    adios (NULL, "only one draft at a time!");
@@ -155,14 +161,14 @@ WhatNow (int argc, char **argv)
 	    drft = cp;
     }
 
-    if (drft == NULL && (drft = getenv ("mhdraft")) == NULL || *drft == 0)
+    if ((drft == NULL && (drft = getenv ("mhdraft")) == NULL) || *drft == 0)
 	drft = getcpy (m_draft (dfolder, dmsg, 1, &isdf));
     msgnam = (cp = getenv ("mhaltmsg")) && *cp ? getcpy (cp) : NULL;
     if (ed == NULL && ((ed = getenv ("mheditor")) == NULL || *ed == 0))
 	ed = NULL, nedit++;
     if ((cp = getenv ("mhuse")) && *cp)
 	use = atoi (cp);
-    if (!nedit && editfile (&ed, NULL, drft, use, NULLMP, msgnam, NULL) < 0)
+    if (!nedit && editfile (&ed, NULL, drft, use, NULL, msgnam, NULL) < 0)
 	done (1);
 
     sprintf (prompt, myprompt, invo_name);
@@ -172,57 +178,69 @@ WhatNow (int argc, char **argv)
 	    done (1);
 	}
 	switch (smatch (*argp, aleqs)) {
-	    case DISPSW: 
-		if (msgnam)
-		    showfile (++argp, msgnam);
-		else
-		    advise (NULL, "no alternate message to display");
-		break;
+	case DISPSW:
+	    /* display the message being replied to, or distributed */
+	    if (msgnam)
+		showfile (++argp, msgnam);
+	    else
+		advise (NULL, "no alternate message to display");
+	    break;
 
-	    case EDITSW: 
-		if (*++argp)
-		    ed = *argp++;
-		if (editfile (&ed, argp, drft, NOUSE, NULLMP, msgnam, NULL)
-			== NOTOK)
-		    done (1);
-		break;
-
-	    case LISTSW: 
-		showfile (++argp, drft);
-		break;
-
-	    case WHOMSW: 
-		whomfile (++argp, drft);
-		break;
-
-	    case QUITSW: 
-		if (*++argp && (*argp[0] == 'd' ||
-			    ((*argp)[0] == '-' && (*argp)[1] == 'd'))) {
-		    if (unlink (drft) == NOTOK)
-			adios (drft, "unable to unlink");
-		}
-		else
-		    if (stat (drft, &st) != NOTOK)
-			advise (NULL, "draft left on %s", drft);
+	case BUILDMIMESW:
+	    /* Translate MIME composition file */
+	    ++argp;
+	    if (build_mime(argp, drft) == NOTOK)
 		done (1);
+	    break;
 
-	    case PUSHSW: 
-		if (sendfile (++argp, drft, 1))
-		    done (1);
-		break;
+	case EDITSW:
+	    /* Call an editor on the draft file */
+	    if (*++argp)
+		ed = *argp++;
+	    if (editfile (&ed, argp, drft, NOUSE, NULL, msgnam, NULL) == NOTOK)
+		done (1);
+	    break;
 
-	    case SENDSW: 
-		sendfile (++argp, drft, 0);
-		break;
+	case LISTSW: 
+	    /* display the draft file */
+	    showfile (++argp, drft);
+	    break;
 
-	    case REFILEOPT: 
-		if (refile (++argp, drft) == 0)
-		    done (0);
-		break;
+	case WHOMSW:
+	    /* Check to whom the draft would be sent */
+	    whomfile (++argp, drft);
+	    break;
 
-	    default: 
-		advise (NULL, "say what?");
-		break;
+	case QUITSW:
+	    if (*++argp && (*argp[0] == 'd' ||
+			    ((*argp)[0] == '-' && (*argp)[1] == 'd'))) {
+		if (unlink (drft) == NOTOK)
+		    adios (drft, "unable to unlink");
+	    } else
+		if (stat (drft, &st) != NOTOK)
+		    advise (NULL, "draft left on %s", drft);
+	    done (1);
+
+	case PUSHSW:
+	    /* Send draft in background */
+	    if (sendfile (++argp, drft, 1))
+		done (1);
+	    break;
+
+	case SENDSW: 
+	    /* Send draft */
+	    sendfile (++argp, drft, 0);
+	    break;
+
+	case REFILEOPT: 
+	    /* Refile the draft */
+	    if (refile (++argp, drft) == 0)
+		done (0);
+	    break;
+
+	default: 
+	    advise (NULL, "say what?");
+	    break;
 	}
     }
     /*NOTREACHED*/
@@ -241,8 +259,8 @@ editfile (char **ed, char **arg, char *file, int use,
           struct msgs *mp, char *altmsg, char *cwd)
 {
     int pid, status;
-    register int vecp;
-    register char *cp;
+    int vecp;
+    char *cp;
     char altpath[BUFSIZ], linkpath[BUFSIZ];
     char *vec[MAXARGS];
     struct stat st;
@@ -258,8 +276,7 @@ editfile (char **ed, char **arg, char *file, int use,
     if (!reedit) {
 	if (*ed == NULL && (*ed = m_find ("editor")) == NULL)
 	    *ed = sysed;
-    }
-    else
+    } else {
 	if (!*ed) {		/* no explicit editor */
 	    *ed = edsave;
 	    if ((cp = r1bindex (*ed, '/')) == NULL)
@@ -268,6 +285,7 @@ editfile (char **ed, char **arg, char *file, int use,
 	    if ((cp = m_find (cp)) != NULL)
 		*ed = cp;
 	}
+    }
 
     if (altmsg) {
 	if (mp == NULL || *altmsg == '/' || cwd == NULL)
@@ -430,14 +448,23 @@ static int
 sendfile (char **arg, char *file, int pushsw)
 {
     pid_t child_id;
-    register int i, vecp;
+    int i, vecp;
     char *cp, *sp, *vec[MAXARGS];
 
 #ifdef MIME
+    /* Translate MIME composition file, if necessary */
+    if ((cp = m_find ("automimeproc"))
+	    && (uleq (cp, "1"))
+	    && !getenv ("NOMHNPROC")
+	    && mhnfile (file)
+	    && (build_mime (NULL, file) == NOTOK))
+	return 0;
+
+    /* For backwards compatibility */
     if ((cp = m_find ("automhnproc"))
 	    && !getenv ("NOMHNPROC")
 	    && mhnfile (file)
-	    && (i = editfile (&cp, NULL, file, NOUSE, NULLMP, NULL, NULL)))
+	    && (i = editfile (&cp, NULL, file, NOUSE, NULL, NULL, NULL)))
 	return 0;
 #endif
 
@@ -484,9 +511,52 @@ sendfile (char **arg, char *file, int pushsw)
 }
 
 
+/*
+ * Translate MIME composition file
+ */
+
+static int
+build_mime (char **argp, char *file)
+{
+    int i;
+    char **args, *ed;
+
+    ed = buildmimeproc;
+
+    /* allocate space for arguments */
+    i = 0;
+    if (argp) {
+	while (argp[i])
+	    i++;
+    }
+    if ((args = (char **) malloc((i + 2) * sizeof(char *))) == NULL)
+	adios (NULL, "unable to malloc memory");
+
+    /* need to add -build if using mhn as buildmimeproc */
+    i = 0;
+    if (strcmp (r1bindex (ed, '/'), "mhn") == 0)
+	args[i++] = "-build";
+
+    /* copy any other arguments */
+    while (argp && *argp)
+	args[i++] = *argp++;
+    args[i] = NULL;
+
+    i = editfile (&ed, args, file, NOUSE, NULL, NULL, NULL);
+    free (args);
+
+    if (i)
+	return NOTOK;
+    else
+	return OK;
+}
 
 #ifdef MIME
 
+/*
+ *  Check if draft is a mhn composition file
+ */
+
 static int
 mhnfile (char *msgnam)
 {
@@ -497,21 +567,26 @@ mhnfile (char *msgnam)
     if ((fp = fopen (msgnam, "r")) == NULL)
 	return 0;
     for (state = FLD;;)
-	switch (state = m_getfld (state, name, buf, sizeof buf, fp)) {
+	switch (state = m_getfld (state, name, buf, sizeof(buf), fp)) {
 	    case FLD:
 	    case FLDPLUS:
 	    case FLDEOF:
+		/*
+		 * If draft already contains any of the
+		 * Content-XXX fields, then assume it already
+		 * been converted.
+		 */
 	        if (uprf (name, XXX_FIELD_PRF)) {
 		    fclose (fp);
 		    return 0;
 		}
 		while (state == FLDPLUS)
-		    state = m_getfld (state, name, buf, sizeof buf, fp);
+		    state = m_getfld (state, name, buf, sizeof(buf), fp);
 		break;
 
 	    case BODY:
 	        do {
-		    register char *bp;
+		    char *bp;
 
 		    for (bp = buf; *bp; bp++)
 			if (*bp != ' ' && *bp != '\t' && *bp != '\n') {
@@ -519,7 +594,7 @@ mhnfile (char *msgnam)
 			    return 1;
 			}
 
-		    state = m_getfld (state, name, buf, sizeof buf, fp);
+		    state = m_getfld (state, name, buf, sizeof(buf), fp);
 		} while (state == BODY);
 		/* and fall... */
 
@@ -790,7 +865,7 @@ sendit (char *sp, char **arg, char *file, int pushed)
 	else {
 	    sprintf (buf, "%s/.signature", mypath);
 	    if ((fp = fopen (buf, "r")) != NULL
-		&& fgets (buf, sizeof buf, fp) != NULL) {
+		&& fgets (buf, sizeof(buf), fp) != NULL) {
 		    fclose (fp);
 		    if (cp = strchr (buf, '\n'))
 			*cp = 0;
@@ -840,7 +915,7 @@ static int
 whomfile (char **arg, char *file)
 {
     pid_t pid;
-    register int vecp;
+    int vecp;
     char *vec[MAXARGS];
 
     m_update ();	/* update the context file */
