@@ -1,6 +1,6 @@
 
 /*
- * dtime.c -- routines to do ``ARPA-style'' time structures
+ * dtime.c -- time/date routines
  *
  * $Id$
  */
@@ -33,6 +33,12 @@ extern char *tzname[];
 # define abs(a) (a >= 0 ? a : -a)
 #endif
 
+/* The time "epoch" */
+#define CENTURY 1900
+
+/*
+ * The number of days in the year, accounting for leap years
+ */
 #define	dysize(y)	\
 	(((y) % 4) ? 365 : (((y) % 100) ? 366 : (((y) % 400) ? 365 : 366)))
 
@@ -98,41 +104,22 @@ static struct zone zones[] = {
     { "X", NULL, 11 },
     { "Y", NULL, 12 },
 #endif
-    NULL
+    { NULL, NULL, 0 }
 };
 
-#define CENTURY 1900
+static int dmsize[] = {
+    31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31
+};
 
 
-char *
-dtimenow(void)
-{
-    time_t clock;
-
-    time (&clock);
-    return dtime (&clock);
-}
-
-
-char *
-dctime (struct tws *tw)
-{
-    static char buffer[25];
-
-    if (!tw)
-	return NULL;
-
-    sprintf (buffer, "%.3s %.3s %02d %02d:%02d:%02d %.4d\n",
-	    tw_dotw[tw->tw_wday], tw_moty[tw->tw_mon], tw->tw_mday,
-	    tw->tw_hour, tw->tw_min, tw->tw_sec,
-	    tw->tw_year >= 100 ? tw->tw_year : CENTURY + tw->tw_year);
-
-    return buffer;
-}
-
+/*
+ * Get current time (adjusted for local time
+ * zone and daylight savings time) expressed
+ * as nmh "broken-down" time structure.
+ */
 
 struct tws *
-dtwstime (void)
+dlocaltimenow (void)
 {
     time_t clock;
 
@@ -141,22 +128,27 @@ dtwstime (void)
 }
 
 
+/*
+ * Take clock value and return pointer to nmh time structure
+ * containing "broken-down" time.  The time is adjusted for
+ * local time zone and daylight savings time.
+ */
+
 struct tws *
 dlocaltime (time_t *clock)
 {
-    register struct tm *tm;
+    static struct tws tw;
+    struct tm *tm;
 
 #if !defined(HAVE_TM_GMTOFF) && !defined(HAVE_TZSET)
     struct timeb tb;
 #endif
 
-    static struct tws tw;
-
     if (!clock)
 	return NULL;
-    tw.tw_flags = TW_NULL;
 
     tm = localtime (clock);
+
     tw.tw_sec  = tm->tm_sec;
     tw.tw_min  = tm->tm_min;
     tw.tw_hour = tm->tm_hour;
@@ -165,6 +157,8 @@ dlocaltime (time_t *clock)
     tw.tw_year = tm->tm_year + CENTURY;
     tw.tw_wday = tm->tm_wday;
     tw.tw_yday = tm->tm_yday;
+
+    tw.tw_flags = TW_NULL;
     if (tm->tm_isdst)
 	tw.tw_flags |= TW_DST;
 
@@ -193,17 +187,23 @@ dlocaltime (time_t *clock)
 }
 
 
+/*
+ * Take clock value and return pointer to nmh time
+ * structure containing "broken-down" time.  Time is
+ * expressed in UTC (Coordinated Universal Time).
+ */
+
 struct tws *
 dgmtime (time_t *clock)
 {
-    register struct tm *tm;
     static struct tws tw;
+    struct tm *tm;
 
     if (!clock)
 	return NULL;
-    tw.tw_flags = TW_NULL;
 
     tm = gmtime (clock);
+
     tw.tw_sec  = tm->tm_sec;
     tw.tw_min  = tm->tm_min;
     tw.tw_hour = tm->tm_hour;
@@ -212,8 +212,11 @@ dgmtime (time_t *clock)
     tw.tw_year = tm->tm_year + CENTURY;
     tw.tw_wday = tm->tm_wday;
     tw.tw_yday = tm->tm_yday;
+
+    tw.tw_flags = TW_NULL;
     if (tm->tm_isdst)
 	tw.tw_flags |= TW_DST;
+
     tw.tw_zone = 0;
 
     tw.tw_flags &= ~TW_SDAY;
@@ -227,6 +230,82 @@ dgmtime (time_t *clock)
 }
 
 
+/*
+ * Using a nmh "broken-down" time structure,
+ * produce a 26-byte date/time string, such as
+ *
+ *	Tue Jan 14 17:49:03 1992\n\0
+ */
+
+char *
+dctime (struct tws *tw)
+{
+    static char buffer[25];
+
+    if (!tw)
+	return NULL;
+
+    sprintf (buffer, "%.3s %.3s %02d %02d:%02d:%02d %.4d\n",
+	    tw_dotw[tw->tw_wday], tw_moty[tw->tw_mon], tw->tw_mday,
+	    tw->tw_hour, tw->tw_min, tw->tw_sec,
+	    tw->tw_year >= 100 ? tw->tw_year : CENTURY + tw->tw_year);
+
+    return buffer;
+}
+
+
+/*
+ * Produce a date/time string of the form
+ *
+ *	Mon, 16 Jun 1992 15:30:48 -700 (or)
+ *	Mon, 16 Jun 1992 15:30:48 EDT
+ *
+ * for the current time, as specified by rfc822.
+ * The first form is required by rfc1123.
+ */
+
+char *
+dtimenow (int alpha_timezone)
+{
+    time_t clock;
+
+    time (&clock);
+    return dtime (&clock, alpha_timezone);
+}
+
+
+/*
+ * Using a local calendar time value, produce
+ * a date/time string of the form
+ *
+ *	Mon, 16 Jun 1992 15:30:48 -700  (or)
+ *	Mon, 16 Jun 1992 15:30:48 EDT
+ *
+ * as specified by rfc822.  The first form is required
+ * by rfc1123 for outgoing messages.
+ */
+
+char *
+dtime (time_t *clock, int alpha_timezone)
+{
+    if (alpha_timezone)
+	/* use alpha-numeric timezones */
+	return dasctime (dlocaltime (clock), TW_NULL);
+    else
+	/* use numeric timezones */
+	return dasctime (dlocaltime (clock), TW_ZONE);
+}
+
+
+/*
+ * Using a nmh "broken-down" time structure, produce
+ * a date/time string of the form
+ *
+ *	Mon, 16 Jun 1992 15:30:48 -0700
+ *
+ * as specified by rfc822 and rfc1123.
+ */
+
 char *
 dasctime (struct tws *tw, int flags)
 {
@@ -238,9 +317,10 @@ dasctime (struct tws *tw, int flags)
 
     /* Display timezone if known */
     if ((tw->tw_flags & TW_SZONE) == TW_SZNIL)
-	    result[0] = '\0';
+	result[0] = '\0';
     else
-	    sprintf(result, " %s", dtimezone(tw->tw_zone, tw->tw_flags | flags));
+	sprintf(result, " %s", dtimezone(tw->tw_zone, tw->tw_flags | flags));
+
     sprintf(buffer, "%02d %s %0*d %02d:%02d:%02d%s",
 	    tw->tw_mday, tw_moty[tw->tw_mon],
 	    tw->tw_year < 100 ? 2 : 4, tw->tw_year,
@@ -258,18 +338,21 @@ dasctime (struct tws *tw, int flags)
 }
 
 
+/*
+ * Get the timezone for given offset
+ */
+
 char *
 dtimezone (int offset, int flags)
 {
-    register int hours, mins;
-    register struct zone *z;
+    int hours, mins;
+    struct zone *z;
     static char buffer[10];
 
     if (offset < 0) {
 	mins = -((-offset) % 60);
 	hours = -((-offset) / 60);
-    }
-    else {
+    } else {
 	mins = offset % 60;
 	hours = offset / 60;
     }
@@ -294,55 +377,15 @@ dtimezone (int offset, int flags)
 }
 
 
-void
-twscopy (struct tws *tb, struct tws *tw)
-{
-#if 0
-    tb->tw_sec   = tw->tw_sec;
-    tb->tw_min   = tw->tw_min;
-    tb->tw_hour  = tw->tw_hour;
-    tb->tw_mday  = tw->tw_mday;
-    tb->tw_mon   = tw->tw_mon;
-    tb->tw_year  = tw->tw_year;
-    tb->tw_wday  = tw->tw_wday;
-    tb->tw_yday  = tw->tw_yday;
-    tb->tw_zone  = tw->tw_zone;
-    tb->tw_clock = tw->tw_clock;
-    tb->tw_flags = tw->tw_flags;
-#else
-    *tb = *tw;  /* struct copy */
-#endif
-}
-
-
-int
-twsort (struct tws *tw1, struct tws *tw2)
-{
-    time_t c1, c2;
-
-    if (tw1->tw_clock == 0)
-	twclock (tw1);
-    if (tw2->tw_clock == 0)
-	twclock (tw2);
-
-    return ((c1 = tw1->tw_clock) > (c2 = tw2->tw_clock) ? 1
-	    : c1 == c2 ? 0 : -1);
-}
-
-
 /*
- * This routine is based on the gtime() routine written by
- * Steven Shafer (sas) at CMU.  It was forwarded to MTR by
- * Jay Lepreau at Utah-CS.
+ * Convert nmh time structure for local "broken-down"
+ * time to calendar time (clock value).  This routine
+ * is based on the gtime() routine written by Steven Shafer
+ * at CMU.  It was forwarded to MTR by Jay Lepreau at Utah-CS.
  */
 
-static int dmsize[] = {
-    31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31
-};
-
-
 time_t
-twclock (struct tws *tw)
+dmktime (struct tws *tw)
 {
     int i, sec, min, hour, mday, mon, year;
     time_t result;
@@ -350,12 +393,13 @@ twclock (struct tws *tw)
     if (tw->tw_clock != 0)
 	return tw->tw_clock;
 
-    if ((sec = tw->tw_sec) < 0 || sec > 59
+    if ((sec = tw->tw_sec) < 0 || sec > 61
 	    || (min = tw->tw_min) < 0 || min > 59
 	    || (hour = tw->tw_hour) < 0 || hour > 23
 	    || (mday = tw->tw_mday) < 1 || mday > 31
 	    || (mon = tw->tw_mon + 1) < 1 || mon > 12)
-	return (tw->tw_clock = -1L);
+	return (tw->tw_clock = (time_t) -1);
+
     year = tw->tw_year;
 
     result = 0;
@@ -380,9 +424,9 @@ twclock (struct tws *tw)
 
 
 /*
- * Simple calculation of day of the week.  Algorithm used is Zeller's
- * congruence.  Currently, we assume if tw->tw_year < 100
- * then the century is CENTURY.
+ * Simple calculation of day of the week.  Algorithm
+ * used is Zeller's congruence.  Currently, we assume
+ * if tw->tw_year < 100, then the century is CENTURY.
  */
 
 void
@@ -409,3 +453,47 @@ set_dotw (struct tws *tw)
 
     tw->tw_flags &= ~TW_SDAY, tw->tw_flags |= TW_SIMP;
 }
+
+
+/*
+ * Copy nmh time structure
+ */
+
+void
+twscopy (struct tws *tb, struct tws *tw)
+{
+#if 0
+    tb->tw_sec   = tw->tw_sec;
+    tb->tw_min   = tw->tw_min;
+    tb->tw_hour  = tw->tw_hour;
+    tb->tw_mday  = tw->tw_mday;
+    tb->tw_mon   = tw->tw_mon;
+    tb->tw_year  = tw->tw_year;
+    tb->tw_wday  = tw->tw_wday;
+    tb->tw_yday  = tw->tw_yday;
+    tb->tw_zone  = tw->tw_zone;
+    tb->tw_clock = tw->tw_clock;
+    tb->tw_flags = tw->tw_flags;
+#else
+    *tb = *tw;  /* struct copy */
+#endif
+}
+
+
+/*
+ * Compare two nmh time structures
+ */
+
+int
+twsort (struct tws *tw1, struct tws *tw2)
+{
+    time_t c1, c2;
+
+    if (tw1->tw_clock == 0)
+	dmktime (tw1);
+    if (tw2->tw_clock == 0)
+	dmktime (tw2);
+
+    return ((c1 = tw1->tw_clock) > (c2 = tw2->tw_clock) ? 1
+	    : c1 == c2 ? 0 : -1);
+}
